@@ -38,7 +38,6 @@ extern "C"
 #include "exp.h"
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <string.h>
 #include <string>
@@ -638,7 +637,7 @@ void Exp_Prior::read_double(double *dparams)
 
   /* starting value for the range parameter */
   d = dparams[1];
-  //myprintf(stdout, "starting d=%g\n", d);
+  //myprintf(mystdout, "starting d=%g\n", d);
 
   /* reset dparams to start after the nugget gamlin params */
   dparams += 13;
@@ -649,7 +648,7 @@ void Exp_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(stdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*myprintf(mystdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, 
@@ -676,7 +675,7 @@ void Exp_Prior::read_ctrlfile(ifstream *ctrlfile)
   /* read the d parameter from the control file */
   ctrlfile->getline(line, BUFFMAX);
   d = atof(strtok(line, " \t\n#"));
-  myprintf(stdout, "starting d=%g\n", d);
+  myprintf(mystdout, "starting d=%g\n", d);
     
   /* read d and nug-hierarchical parameters (mix of gammas) */
   ctrlfile->getline(line, BUFFMAX);
@@ -686,7 +685,7 @@ void Exp_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(stdout, "fixing d prior\n"); }
+    { fix_d = true; myprintf(mystdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -851,7 +850,7 @@ void Exp_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void Exp_Prior::Print(FILE *outfile)
 {
-  myprintf(stdout, "corr prior: isotropic power\n");
+  myprintf(mystdout, "corr prior: isotropic power\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
@@ -866,7 +865,7 @@ void Exp_Prior::Print(FILE *outfile)
   /* range gamma hyperprior */
   if(fix_d) myprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(stdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    myprintf(mystdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
