@@ -27,7 +27,6 @@
 #include "matrix.h"
 #include <assert.h>
 #include <math.h>
-#include <stdio.h>
 #include <stdlib.h>
 
 
@@ -67,6 +66,23 @@ void zero(double **M, unsigned int n1, unsigned int n2)
 }
 
 
+/*
+ * check if a (square) matrix is zeros
+ */
+
+int isZero(double **M, unsigned int m, int sym)
+{
+  unsigned int i,j, upto;
+  for(j=0; j<m; j++) {
+    upto = m;
+    if(sym) upto = j+1;
+    for(i=0; i<upto; i++)
+      if(M[j][i] != 0.0) return 0;
+  }
+  return 1;
+}
+
+
 /*
  * replace square matrix with identitiy 
  */
@@ -106,6 +122,19 @@ double ** new_zero_matrix(unsigned int n1, unsigned int n2)
 }
 
 
+/*
+ * same as new_imatrix, but zeros out the matrix
+ */
+
+int ** new_zero_imatrix(unsigned int n1, unsigned int n2)
+{
+  unsigned int i, j;
+  int **m = new_imatrix(n1, n2);
+  for(i=0; i<n1; i++) for(j=0; j<n2; j++) m[i][j] = 0;
+  return m;
+}
+
+
 /*
  * create a new n1 x n2 matrix which is allocated like
  * and n1*n2 array, but can be referenced as a 2-d array
@@ -226,6 +255,27 @@ double ** new_dup_matrix(double** M, unsigned int n1, unsigned int n2)
   return m;
 }
 
+
+/*
+ * create a new n1 x n2 matrix which is allocated like
+ * and n1*n2 array, and copy the of n1 x n2 M into it.
+ */
+
+int ** new_dup_imatrix(int** M, unsigned int n1, unsigned int n2)
+{
+  int **m;
+
+  if(n1 <= 0 || n2 <= 0) {
+    /* assert(M == NULL); */
+    return NULL;
+  }
+ 
+  m = new_imatrix(n1, n2);
+  dup_imatrix(m, M, n1, n2);
+  return m;
+}
+
+
 /*
  * create a new n1 x (n2-1) matrix which is allocated like
  * an n1*(n2-1) array, and copy M[n1][2:n2] into it.
@@ -240,9 +290,9 @@ double ** new_shift_matrix(double** M, unsigned int n1, unsigned int n2)
     return NULL;
   }
   m = new_matrix(n1, (n2-1));
-  /* printMatrix(M, n1, n2, stdout); */
+  /* printMatrix(M, n1, n2, mystdout); */
   for(i=0; i<n1; i++) for(j=0; j<(n2-1); j++) m[i][j] = M[i][j+1];
-  /* printMatrix(m, n1, (n2-1), stdout); */
+  /* printMatrix(m, n1, (n2-1), mystdout); */
   return m;
 }
 
@@ -260,6 +310,19 @@ void dup_matrix(double** M1, double **M2, unsigned int n1, unsigned int n2)
 }
 
 
+/*
+ * copy M2 to M1 for integer matrices
+ */
+
+void dup_imatrix(int** M1, int **M2, unsigned int n1, unsigned int n2)
+{
+  unsigned int i;
+  if(n1 == 0 || n2 == 0) return;
+  assert(M1 && M2);
+  for(i=0; i<n1; i++) dupiv(M1[i], M2[i], n2);
+}
+
+
 /*
  * swap the pointers of M2 to M1, and vice-versa
  * (tries to aviod dup_matrix when unnecessary)
@@ -321,6 +384,48 @@ double ** new_bigger_matrix(double** M, unsigned int n1, unsigned int n2,
 }
 
 
+/*
+ * create a bigger n1 x n2 matrix which is allocated like
+ * and n1*n2 array, and copy the of n1 x n2 M into it.
+ * deletes the old matrix -- integer version
+ */
+
+int ** new_bigger_imatrix(int** M, unsigned int n1, unsigned int n2, 
+			  unsigned int n1_new, unsigned int n2_new)
+{
+  int i;
+  int **m;
+  
+  assert(n1_new >= n1);
+  assert(n2_new >= n2);
+  
+  if(n1_new <= 0 || n2_new <= 0) {
+    assert(M == NULL);
+    return NULL;
+  }
+  
+  if(M == NULL) {
+    assert(n1 == 0 || n2 == 0);
+    return new_zero_imatrix(n1_new, n2_new);
+  }
+  
+  if(n2 == n2_new) {
+    m = (int**) malloc(sizeof(int*) * n1_new);
+    assert(m);
+    m[0] = realloc(M[0], sizeof(int) * n1_new * n2_new);
+    free(M);
+    assert(m[0]);
+    for(i=1; i<n1_new; i++) m[i] = m[i-1] + n2_new;
+    zeroiv(m[n1], (n1_new-n1)*n2_new);
+  } else {
+    m = new_zero_imatrix(n1_new, n2_new);
+    dup_imatrix(m, M, n1, n2);
+    delete_imatrix(M);
+  }
+  return m;
+}
+
+
 /*
  * create a new n1 x n2 matrix which is allocated like
  * and n1*n2 array, and copy the of n1 x n2 M into it.
@@ -398,8 +503,8 @@ void printMatrix(double **M, unsigned int n, unsigned int col, FILE *outfile)
   for(i=0; i<n; i++) {
     for(j=0; j<col; j++) {
 #ifdef DEBUG
-      if(j==col-1) myprintf(outfile, "%.20f\n", M[i][j]);
-      else myprintf(outfile, "%.20f ", M[i][j]);
+      if(j==col-1) myprintf(outfile, "%15f\n", M[i][j]);
+      else myprintf(outfile, "%15f ", M[i][j]);
 #else
       if(j==col-1) myprintf(outfile, "%g\n", M[i][j]);
       else myprintf(outfile, "%g ", M[i][j]);
@@ -628,10 +733,33 @@ void sum_of_columns_f(double *s, double **M, unsigned int n1, unsigned int n2,
   if(n1 <= 0 || n2 <= 0) {return;}
   assert(s && M);
   
-  /* calculate mean of columns */
+  /* calculate sum of columns */
   for(i=0; i<n2; i++) {
-    s[i] = 0;
-    for(j=0; j<n1; j++) s[i] += f(M[j][i]);
+    s[i] = f(M[0][i]);
+    for(j=1; j<n1; j++) s[i] += f(M[j][i]);
+  }
+}
+
+
+/*
+ * sum_of_columns:
+ *
+ * fill sum[n1] with the sum of the columns of M (n1 x n2);
+ * each element of which is sent through function f() first;
+ */
+
+void sum_of_columns(double *s, double **M, unsigned int n1, unsigned int n2)
+{
+  unsigned int i,j;
+
+  /* sanity checks */
+  if(n1 <= 0 || n2 <= 0) {return;}
+  assert(s && M);
+  
+  /* calculate sum of columns */
+  for(i=0; i<n2; i++) {
+    s[i] = M[0][0];
+    for(j=1; j<n1; j++) s[i] += M[j][i];
   }
 }
 
@@ -653,10 +781,11 @@ void sum_of_each_column_f(double *s, double **M, unsigned int *n1,
   if(n2 <= 0) {return;}
   assert(s && M);
   
-  /* calculate mean of columns */
+  /* calculate sum of columns */
   for(i=0; i<n2; i++) {
-    s[i] = 0;
-    for(j=0; j<n1[i]; j++) s[i] += f(M[j][i]);
+    if(n1[i] > 0) s[i] = f(M[0][i]);
+    else s[i] = 0;
+    for(j=1; j<n1[i]; j++) s[i] += f(M[j][i]);
   }
 }
 
@@ -1154,55 +1283,58 @@ int* find(double *V, unsigned int n, FIND_OP op, double val, unsigned int* len)
  * EQ(==) LEQ(<=) GEQ(>=) NE(!=)
  */
 
-int* find_col(double **V, unsigned int n, unsigned int var, 
-	FIND_OP op, double val, unsigned int* len)
+int* find_col(double **V, int *pv, unsigned int n, 
+	      unsigned int var, FIND_OP op, double val, 
+	      unsigned int* len)
 {
   unsigned int i,j;
-  int *tf;
+  int *tf, *p;
   int *found;
   
   tf = new_ivector(n);
+  if(pv) p = pv;
+  else p = iseq(0,n-1);
   
   (*len) = 0;
   switch (op) {
   case GT:  
     for(i=0; i<n; i++) {
-      if(V[i][var] >  val) tf[i] = 1; 
+      if(V[p[i]][var] >  val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
     break;
   case GEQ: 
     for(i=0; i<n; i++) {
-      if(V[i][var] >= val) tf[i] = 1; 
+      if(V[p[i]][var] >= val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
     break;
   case EQ:  
     for(i=0; i<n; i++) {
-      if(V[i][var] == val) tf[i] = 1; 
+      if(V[p[i]][var] == val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
     break;
   case LEQ: 
     for(i=0; i<n; i++) {
-      if(V[i][var] <= val) tf[i] = 1; 
+      if(V[p[i]][var] <= val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
     break;
   case LT:  
     for(i=0; i<n; i++) {
-      if(V[i][var] <  val) tf[i] = 1; 
+      if(V[p[i]][var] <  val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
     break;
   case NE:  
     for(i=0; i<n; i++) {
-      if(V[i][var] != val) tf[i] = 1; 
+      if(V[p[i]][var] != val) tf[i] = 1; 
       else tf[i] = 0; 
       if(tf[i] == 1) (*len)++;
     }
@@ -1222,6 +1354,7 @@ int* find_col(double **V, unsigned int n, unsigned int var,
   }
   
   free(tf);
+  if(!pv) free(p);
   return found;
 }
 
@@ -1448,6 +1581,43 @@ double **new_p_submatrix(int *p, double **v, unsigned int nrows,
 }
 
 
+/*
+ * sub_p_matrix_rows:
+ *
+ * copy the rows v[1:n1][p[n2]] to V.  
+ * must have ncol(v) == ncol(V) and nrow(V) >= lenp
+ * and nrow(v) >= max(p)
+ */
+
+void sub_p_matrix_rows(double **V, int *p, double **v, 
+		       unsigned int ncols, unsigned int lenp, 
+		       unsigned int row_offset)
+{
+  int i;
+  assert(V); assert(p); assert(v); assert(ncols > 0 && lenp > 0);
+  for(i=0; i<lenp; i++) 
+    dupv(V[i+row_offset], v[p[i]], ncols);
+}
+
+
+/*
+ * new_p_submatrix_rows:
+ *
+ * create a new matrix from the rows of v, specified
+ * by p.  Must have have ncol(v) == ncol(V) and nrow(V) >= nrows
+ * and nrow(v) >= max(p)
+ */
+
+double **new_p_submatrix_rows(int *p, double **v, unsigned int nrows, 
+			      unsigned int ncols, unsigned int row_offset)
+{
+  double **V;
+  if(nrows+row_offset == 0 || ncols == 0) return NULL;
+  V = new_matrix(nrows + row_offset, ncols);
+  if(nrows > 0) sub_p_matrix_rows(V, p, v, ncols, nrows, row_offset);
+  return(V);
+}
+
 /*
  * copy_p_matrix:
  *
@@ -1477,7 +1647,7 @@ void check_means(double *mean, double *q1, double *median,
   int replace = 0;
   for(i=0; i<n; i++) {
     if(mean[i] > q2[i] || mean[i] < q1[i]) {
-      myprintf(stdout, "replacing %g with (%g,%g,%g)\n", 
+      myprintf(mystdout, "replacing %g with (%g,%g,%g)\n", 
 	       mean[i], q1[i], median[i], q2[i]);
       mean[i] = median[i];
       replace++;
@@ -1486,7 +1656,7 @@ void check_means(double *mean, double *q1, double *median,
   
   /* let us know what happened */
   if(replace > 0) 
-    myprintf(stdout, "NOTICE: %d predictive means replaced with medians\n", 
+    myprintf(mystdout, "NOTICE: %d predictive means replaced with medians\n", 
 	     replace);
 }
 
@@ -1503,7 +1673,7 @@ unsigned int matrix_constrained(int *p, double **X, unsigned int n1,
 {
   unsigned int i,j, count;
   count = 0;
-  /* printRect(stderr, rect->d, rect->boundary); */
+  /* printRect(mystderr, rect->d, rect->boundary); */
   for(i=0; i<n1; i++) {
     p[i] = 1;
     for(j=0; j<n2; j++) {
@@ -1546,6 +1716,25 @@ Rect* new_rect(unsigned int d)
 }
 
 
+/*
+ * create a new rectangle structure with the boundary populated
+ * by the contents of a double array
+ */
+
+Rect* new_drect(double **drect, int d)
+{
+  unsigned int i;
+  Rect *rect = new_rect(d);
+  for(i=0; i<d; i++) {
+    rect->boundary[0][i] = drect[0][i];
+    rect->boundary[1][i] = drect[1][i];
+    rect->opl[i] = GEQ;
+    rect->opr[i] = LEQ;
+  }
+  return rect;
+}
+
+
 /*
  * return a pointer to a duplicated rectangle structure
  */
@@ -1655,7 +1844,7 @@ void normalize(double **X, double **rect, int N, int d, double normscale)
 	X[j][i] = (X[j][i] - rect[0][i]) / norm;
       X[j][i] = normscale * X[j][i];
       /* if(!(X[j][i] >=0 && X[j][i] <= normscale))
-	myprintf(stdout, "X[%d][%d] = %g, normscale = %g\n", j, i, X[j][i], normscale);
+	myprintf(mystdout, "X[%d][%d] = %g, normscale = %g\n", j, i, X[j][i], normscale);
 	assert(X[j][i] >=0 && X[j][i] <= normscale); */
     }
   }
@@ -1971,6 +2160,21 @@ void add_vector(double a, double *v1, double b, double *v2, unsigned int n)
 }
 
 
+/*
+ * add two integer vectors of the same size 
+ * v1 = v1 + v2
+ */
+
+void add_ivector(int *v1, int *v2, unsigned int n)
+{
+  unsigned int i;
+  if(n == 0) return;
+  assert(n > 0);
+  assert(v1 && v2);
+  for(i=0; i<n; i++) v1[i] += v2[i];
+}
+
+
 /*
  * add_p_vector:
  *
@@ -1994,7 +2198,7 @@ void printVector(double *v, unsigned int n, FILE *outfile, PRINT_PREC type)
 {
   unsigned int i;
   if(type==HUMAN) for(i=0; i<n; i++) myprintf(outfile, "%g ", v[i]);
-  else if(type==MACHINE) for(i=0; i<n; i++) myprintf(outfile, "%.20f ", v[i]);
+  else if(type==MACHINE) for(i=0; i<n; i++) myprintf(outfile, "%15f ", v[i]);
   else error("bad PRINT_PREC type");
   myprintf(outfile, "\n");
 }
@@ -2015,7 +2219,7 @@ void printSymmMatrixVector(double **m, unsigned int n, FILE *outfile,
   else if(type==MACHINE) 
     for(i=0; i<n; i++) 
       for(j=i; j<n; j++) 
-	myprintf(outfile, "%.20f ", m[i][j]);
+	myprintf(outfile, "%15f ", m[i][j]);
   else error("bad PRINT_PREC type");
   myprintf(outfile, "\n");
 }
