@@ -24,7 +24,6 @@
 
 #include <math.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
 #include <Rmath.h> 
 #include "rand_pdf.h"
@@ -155,7 +154,7 @@ double **cov;
   discrim = linalg_ddot(n, xx, 1, xx, 1);
   free(xx);
   
-  /*myprintf(stderr, "discrim = %g, log(deg_sigma) = %g\n", discrim, log_det_sigma);*/
+  /*myprintf(mystderr, "discrim = %g, log(deg_sigma) = %g\n", discrim, log_det_sigma);*/
   return -0.5 * (discrim + log_det_sigma) - n*M_LN_SQRT_2PI;
 }
 
